==> resteasy-integration-tests-5.0.8.Final.zip: src/test/java/org/jboss/resteasy/test/providers/multipart/resource/InputPartDefaultCharsetOverwriteService.java <==
package org.jboss.resteasy.test.providers.multipart.resource;

import java.io.IOException;
import java.util.List;

import javax.ws.rs.Consumes;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import org.jboss.logging.Logger;
import org.jboss.resteasy.plugins.providers.multipart.InputPart;
import org.jboss.resteasy.plugins.providers.multipart.MultipartInput;

@Path("")
public class InputPartDefaultCharsetOverwriteService {
    private static Logger logger = Logger.getLogger(InputPartDefaultCharsetOverwriteService.class);

    @POST
    @Path("test")
    @Consumes(MediaType.MULTIPART_FORM_DATA)
    @Produces(MediaType.TEXT_PLAIN)
    public Response testDefaultContentType(MultipartInput input) throws IOException {
        List<InputPart> parts = input.getParts();
        InputPart part = parts.get(0);
        String s1 = part.getBody(String.class, null);
        String s2 = part.getBodyAsString();
        String result = part.getMediaType() + ":" + s1 + ":" + s2;
        logger.info("server response: " + result);
        return Response.ok(result, part.getMediaType()).build();
    }

    @POST
    @Path("query")
    @Consumes(MediaType.MULTIPART_FORM_DATA)
    @Produces(MediaType.TEXT_PLAIN)
    public Response testInputPartSetMediaType(@QueryParam("contentType") String mediaType, MultipartInput input)
            throws IOException {
        List<InputPart> parts = input.getParts();
        InputPart part = parts.get(0);
        part.setMediaType(MediaType.valueOf(mediaType));
        String s1 = part.getBody(String.class, null);
        String s2 = part.getBodyAsString();
        String result = part.getMediaType() + ":" + s1 + ":" + s2;
        logger.info("server response: " + result);
        return Response.ok(result, part.getMediaType()).build();
    }

    @POST
    @Path("bytes")
    @Consumes(MediaType.WILDCARD)
    @Produces(MediaType.APPLICATION_OCTET_STREAM)
    public Response testByteArray(MultipartInput input) throws IOException {
        List<InputPart> parts = input.getParts();
        InputPart part = parts.get(0);
        byte[] b = part.getBody(byte[].class, null);
        return Response.ok(b).build();
    }
}

==> resteasy-integration-tests-6.2.12.Final.zip: src/test/java/org/jboss/resteasy/test/providers/multipart/resource/InputPartDefaultCharsetOverwriteService.java <==
package org.jboss.resteasy.test.providers.multipart.resource;

import java.io.IOException;
import java.util.List;

import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.QueryParam;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Response;

import org.jboss.logging.Logger;
import org.jboss.resteasy.plugins.providers.multipart.InputPart;
import org.jboss.resteasy.plugins.providers.multipart.MultipartInput;

@Path("")
public class InputPartDefaultCharsetOverwriteService {
    private static Logger logger = Logger.getLogger(InputPartDefaultCharsetOverwriteService.class);

    @POST
    @Path("test")
    @Consumes(MediaType.MULTIPART_FORM_DATA)
    @Produces(MediaType.TEXT_PLAIN)
    public Response testDefaultContentType(MultipartInput input) throws IOException {
        List<InputPart> parts = input.getParts();
        InputPart part = parts.get(0);
        String s1 = part.getBody(String.class, null);
        String s2 = part.getBodyAsString();
        String result = part.getMediaType() + ":" + s1 + ":" + s2;
        logger.info("server response: " + result);
        return Response.ok(result, part.getMediaType()).build();
    }

    @POST
    @Path("query")
    @Consumes(MediaType.MULTIPART_FORM_DATA)
    @Produces(MediaType.TEXT_PLAIN)
    public Response testInputPartSetMediaType(@QueryParam("contentType") String mediaType, MultipartInput input)
            throws IOException {
        List<InputPart> parts = input.getParts();
        InputPart part = parts.get(0);
        part.setMediaType(MediaType.valueOf(mediaType));
        String s1 = part.getBody(String.class, null);
        String s2 = part.getBodyAsString();
        String result = part.getMediaType() + ":" + s1 + ":" + s2;
        logger.info("server response: " + result);
        return Response.ok(result, part.getMediaType()).build();
    }

    @POST
    @Path("bytes")
    @Consumes(MediaType.WILDCARD)
    @Produces(MediaType.APPLICATION_OCTET_STREAM)
    public Response testByteArray(MultipartInput input) throws IOException {
        List<InputPart> parts = input.getParts();
        InputPart part = parts.get(0);
        byte[] b = part.getBody(byte[].class, null);
        return Response.ok(b).build();
    }
}
